@@ -96,6 +96,10 @@ def date_range_params(period_config, comparison, period, reference_date):
         start_date = (today + relativedelta(days=-30)).strftime("%Y-%m-%d")
         end_date = today.strftime("%Y-%m-%d")
 
+    elif period_config == "l45d":
+        start_date = (today + relativedelta(days=-45)).strftime("%Y-%m-%d")
+        end_date = today.strftime("%Y-%m-%d")
+
     elif period_config == "previous_l30d":
         start_date = (today + relativedelta(days=-60)).strftime("%Y-%m-%d")
         end_date = (today + relativedelta(days=-30)).strftime("%Y-%m-%d")
@@ -108,6 +112,11 @@ def date_range_params(period_config, comparison, period, reference_date):
         start_date = (today + relativedelta(years=-1)).strftime("%Y-%m-01")
         end_date = (today + relativedelta(years=-1) + relativedelta(months=1)).strftime("%Y-%m-01")
 
+    elif period_config == "lymtd":
+        start_date = (today + relativedelta(years=-1)).strftime("%Y-%m-01")
+        end_date = (today + relativedelta(years=-1)).strftime("%Y-%m-%d")
+
+
 
     else:
         return {}
@@ -185,19 +194,17 @@ class DataSource:
     def _get_query_list(self, layer_name, query_name=None):
         folder_path = self._build_folder_path(layer_name)
 
-        jinja_env = jinja2.Environment()
-
         params = {}
         if os.path.isfile(self._build_root_folder_path() + "params.yaml"):
             params = yaml.load(
-                jinja_env.from_string(open(self._build_root_folder_path() + "params.yaml").read()).render(),
+                self.jinja_env.from_string(open(self._build_root_folder_path() + "params.yaml").read()).render(),
                 Loader=yaml.FullLoader)
         if os.path.isfile(folder_path + "params.yaml"):
             params.update(yaml.load(
-                jinja_env.from_string(open(folder_path + "params.yaml").read()).render(),
+                self.jinja_env.from_string(open(folder_path + "params.yaml").read()).render(),
                 Loader=yaml.FullLoader))
         config = yaml.load(
-            jinja_env.from_string(open(folder_path + "config.yaml").read()).render(params),
+            self.jinja_env.from_string(open(folder_path + "config.yaml").read()).render(params),
             Loader=yaml.FullLoader)
 
         queries = config.get("queries")
